@@ -28,12 +28,12 @@ import feedparser
 import pango
 import hildon
 #import gtkhtml2
-try:
-    import webkit
-    has_webkit=True
-except:
-    import gtkhtml2
-    has_webkit=False
+#try:
+import webkit
+#    has_webkit=True
+#except:
+#    import gtkhtml2
+#    has_webkit=False
 import time
 import dbus
 import pickle
@@ -120,42 +120,42 @@ class AddWidgetWizard(hildon.WizardDialog):
         else:
             return True
 
-class GetImage(threading.Thread):
-    def __init__(self, url, stream):
-        threading.Thread.__init__(self)
-        self.url = url
-        self.stream = stream
-    
-    def run(self):
-        f = urllib2.urlopen(self.url)
-        data = f.read()
-        f.close()
-        self.stream.write(data)
-        self.stream.close()
-
-class ImageDownloader():
-    def __init__(self):
-        self.images = []
-        self.downloading = False
-        
-    def queueImage(self, url, stream):
-        self.images.append((url, stream))
-        if not self.downloading:
-            self.downloading = True
-            gobject.timeout_add(50, self.checkQueue)
-        
-    def checkQueue(self):
-        for i in range(4-threading.activeCount()):
-            if len(self.images) > 0:
-                (url, stream) = self.images.pop() 
-                GetImage(url, stream).start()
-        if len(self.images)>0:
-            gobject.timeout_add(200, self.checkQueue)
-        else:
-            self.downloading=False
-            
-    def stopAll(self):
-        self.images = []
+#class GetImage(threading.Thread):
+#    def __init__(self, url, stream):
+#        threading.Thread.__init__(self)
+#        self.url = url
+#        self.stream = stream
+#    
+#    def run(self):
+#        f = urllib2.urlopen(self.url)
+#        data = f.read()
+#        f.close()
+#        self.stream.write(data)
+#        self.stream.close()
+#
+#class ImageDownloader():
+#    def __init__(self):
+#        self.images = []
+#        self.downloading = False
+#        
+#    def queueImage(self, url, stream):
+#        self.images.append((url, stream))
+#        if not self.downloading:
+#            self.downloading = True
+#            gobject.timeout_add(50, self.checkQueue)
+#        
+#    def checkQueue(self):
+#        for i in range(4-threading.activeCount()):
+#            if len(self.images) > 0:
+#                (url, stream) = self.images.pop() 
+#                GetImage(url, stream).start()
+#        if len(self.images)>0:
+#            gobject.timeout_add(200, self.checkQueue)
+#        else:
+#            self.downloading=False
+#            
+#    def stopAll(self):
+#        self.images = []
         
         
 class Download(threading.Thread):
@@ -168,9 +168,9 @@ class Download(threading.Thread):
     def run (self):
         (use_proxy, proxy) = self.config.getProxy()
         if use_proxy:
-            self.listing.updateFeed(self.key, self.config.getExpiry(), proxy=proxy)
+            self.listing.updateFeed(self.key, self.config.getExpiry(), proxy=proxy, imageCache=self.config.getImageCache() )
         else:
-            self.listing.updateFeed(self.key, self.config.getExpiry())
+            self.listing.updateFeed(self.key, self.config.getExpiry(), imageCache=self.config.getImageCache() )
 
         
 class DownloadBar(gtk.ProgressBar):
@@ -370,48 +370,50 @@ class SortList(gtk.Dialog):
                
 
 class DisplayArticle(hildon.StackableWindow):
-    def __init__(self, title, text, link, index, key, listing, config):
+    def __init__(self, feed, id, key, config, listing):
         hildon.StackableWindow.__init__(self)
-        self.imageDownloader = ImageDownloader()
+        #self.imageDownloader = ImageDownloader()
+        self.feed = feed
         self.listing=listing
         self.key = key
-        self.index = index
-        self.text = text
-        self.link = link
-        self.set_title(title)
+        self.id = id
+        self.set_title(feed.getTitle(id))
         self.config = config
-        self.images = []
         
         # Init the article display
-        if self.config.getWebkitSupport():
-            self.view = webkit.WebView()
+        #if self.config.getWebkitSupport():
+        self.view = webkit.WebView()
             #self.view.set_editable(False)
-        else:
-            import gtkhtml2
-            self.view = gtkhtml2.View()
-            self.document = gtkhtml2.Document()
-            self.view.set_document(self.document)
-            self.document.connect("link_clicked", self._signal_link_clicked)
+        #else:
+        #    import gtkhtml2
+        #    self.view = gtkhtml2.View()
+        #    self.document = gtkhtml2.Document()
+        #    self.view.set_document(self.document)
+        #    self.document.connect("link_clicked", self._signal_link_clicked)
         self.pannable_article = hildon.PannableArea()
         self.pannable_article.add(self.view)
         #self.pannable_article.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
         #self.gestureId = self.pannable_article.connect('horizontal-movement', self.gesture)
 
-        if self.config.getWebkitSupport():
-            if key=="ArchivedArticles":
-                self.view.open("file://" + self.link)
-            else:
-                self.view.load_html_string(self.text, self.link) # "text/html", "utf-8", self.link)
-            self.view.set_zoom_level(float(config.getArtFontSize())/10.)
-        else:
-            if not key == "ArchivedArticles":
+        #if self.config.getWebkitSupport():
+        contentLink = self.feed.getContentLink(self.id)
+        self.feed.setEntryRead(self.id)
+        #if key=="ArchivedArticles":
+        self.view.open("file://" + contentLink)
+        self.view.connect("motion-notify-event", lambda w,ev: True)
+
+        #else:
+        #self.view.load_html_string(self.text, contentLink) # "text/html", "utf-8", self.link)
+        self.view.set_zoom_level(float(config.getArtFontSize())/10.)
+        #else:
+        #    if not key == "ArchivedArticles":
                 # Do not download images if the feed is "Archived Articles"
-                self.document.connect("request-url", self._signal_request_url)
+        #        self.document.connect("request-url", self._signal_request_url)
             
-            self.document.clear()
-            self.document.open_stream("text/html")
-            self.document.write_stream(self.text)
-            self.document.close_stream()
+        #    self.document.clear()
+        #    self.document.open_stream("text/html")
+        #    self.document.write_stream(self.text)
+        #    self.document.close_stream()
         
         menu = hildon.AppMenu()
         # Create a button and add it to the menu
@@ -422,7 +424,7 @@ class DisplayArticle(hildon.StackableWindow):
         
         button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
         button.set_label("Open in Browser")
-        button.connect("clicked", self._signal_link_clicked, self.link)
+        button.connect("clicked", self._signal_link_clicked, self.feed.getExternalLink(self.id))
         menu.append(button)
         
         button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
@@ -456,9 +458,9 @@ class DisplayArticle(hildon.StackableWindow):
         
         if (abs(y) < 30):
             if (x > 15):
-                self.emit("article-previous", self.index)
+                self.emit("article-previous", self.id)
             elif (x<-15):
-                self.emit("article-next", self.index)   
+                self.emit("article-next", self.id)   
         #print x, y
         #print "Released"
 
@@ -472,8 +474,8 @@ class DisplayArticle(hildon.StackableWindow):
 
     def destroyWindow(self, *args):
         self.disconnect(self.destroyId)
-        self.emit("article-closed", self.index)
-        self.imageDownloader.stopAll()
+        self.emit("article-closed", self.id)
+        #self.imageDownloader.stopAll()
         self.destroy()
         
     def horiz_scrolling_button(self, *widget):
@@ -482,7 +484,7 @@ class DisplayArticle(hildon.StackableWindow):
         
     def archive_button(self, *widget):
         # Call the listing.addArchivedArticle
-        self.listing.addArchivedArticle(self.key, self.index)
+        self.listing.addArchivedArticle(self.key, self.id)
         
     #def reloadArticle(self, *widget):
     #    if threading.activeCount() > 1:
@@ -497,14 +499,14 @@ class DisplayArticle(hildon.StackableWindow):
     #    self.show_all()
 
     def _signal_link_clicked(self, object, link):
-        bus = dbus.SystemBus()
+        bus = dbus.SessionBus()
         proxy = bus.get_object("com.nokia.osso_browser", "/com/nokia/osso_browser/request")
         iface = dbus.Interface(proxy, 'com.nokia.osso_browser')
-        iface.load_url(link)
+        iface.open_new_window(link)
 
-    def _signal_request_url(self, object, url, stream):
+    #def _signal_request_url(self, object, url, stream):
         #print url
-        self.imageDownloader.queueImage(url, stream)
+    #    self.imageDownloader.queueImage(url, stream)
         #imageThread = GetImage(url)
         #imageThread.start()
         #self.images.append((stream, imageThread))
@@ -585,10 +587,12 @@ class DisplayFeed(hildon.StackableWindow):
         self.show_all()
         
     def clear(self):
-        self.remove(self.pannableFeed)
+        self.pannableFeed.destroy()
+        #self.remove(self.pannableFeed)
 
     def button_clicked(self, button, index, previous=False, next=False):
-        newDisp = DisplayArticle(self.feedTitle, self.feed.getArticle(index), self.feed.getLink(index), index, self.key, self.listing, self.config)
+        #newDisp = DisplayArticle(self.feedTitle, self.feed.getArticle(index), self.feed.getLink(index), index, self.key, self.listing, self.config)
+        newDisp = DisplayArticle(self.feed, index, self.key, self.config, self.listing)
         stack = hildon.WindowStack.get_default()
         if previous:
             tmp = stack.peek()
@@ -687,14 +691,14 @@ class FeedingIt:
         self.mainVbox.pack_start(self.pannableListing)
         self.window.add(self.mainVbox)
         self.window.show_all()
-        self.config = Config(self.window, CONFIGDIR+"config.ini", has_webkit)
+        self.config = Config(self.window, CONFIGDIR+"config.ini")
         gobject.idle_add(self.createWindow)
         
     def createWindow(self):
         self.listing = Listing(CONFIGDIR)
         
         self.downloadDialog = False
-        self.orientation = FremantleRotation("FeedingIt", main_window=self.window)
+        self.orientation = FremantleRotation("FeedingIt", main_window=self.window, app=self)
         self.orientation.set_mode(self.config.getOrientation())
         
         menu = hildon.AppMenu()
@@ -732,8 +736,8 @@ class FeedingIt:
         self.window.set_app_menu(menu)
         menu.show_all()
         
-        #self.feedWindow = hildon.StackableWindow()
-        #self.articleWindow = hildon.StackableWindow()
+        self.feedWindow = hildon.StackableWindow()
+        self.articleWindow = hildon.StackableWindow()
 
         self.displayListing()
         self.autoupdate = False
@@ -745,6 +749,8 @@ class FeedingIt:
             feed = self.listing.getFeed(key)
             for id in feed.getIds():
                 feed.setEntryRead(id)
+            feed.saveUnread(CONFIGDIR)
+            self.listing.updateUnread(key, feed.getNumberOfUnreadItems())
         self.refreshList()
 
     def button_export_clicked(self, button):
@@ -840,8 +846,8 @@ class FeedingIt:
                 break
 
     def buttonFeedClicked(widget, button, self, window, key):
-        disp = DisplayFeed(self.listing, self.listing.getFeed(key), self.listing.getFeedTitle(key), key, self.config)
-        disp.connect("feed-closed", self.onFeedClosed)
+        self.disp = DisplayFeed(self.listing, self.listing.getFeed(key), self.listing.getFeedTitle(key), key, self.config)
+        self.disp.connect("feed-closed", self.onFeedClosed)
 
     def onFeedClosed(self, object, key):
         #self.displayListing()
